Skip to contents

Converts pressure readings from vented or unvented water-level sensors to water height in meters.

Usage

calc_water_height(sensor_kPa, atmo_kPa = NULL, water_temp, type = "vented")

Arguments

sensor_kPa

Numeric vector. Sensor pressure in kilopascals. For type = "vented", this is differential pressure from the water column. For type = "unvented", this is absolute pressure.

atmo_kPa

Numeric vector. Atmospheric pressure in kilopascals. Required when type = "unvented".

water_temp

Numeric vector. Water temperature in degrees Celsius.

type

Character string. Sensor type, either "vented" or "unvented". Defaults to "vented".

Value

Numeric vector of water height in meters.

Details

The pressure difference is divided by water density and gravitational acceleration. Water density is calculated with calc_water_density().

References

Tanaka, M., Girard, G., Davis, R., Peuto, A., and Bignell, N. (2001). Recommended table for the density of water between 0°C and 40°C based on recent experimental reports. Metrologia, 38(4), 301-309. doi:10.1088/0026-1394/38/4/3

Examples

calc_water_height(sensor_kPa = 19.2, water_temp = 15, type = "vented")
#> [1] 1.959614

calc_water_height(
  sensor_kPa = 120.5,
  atmo_kPa = 101.3,
  water_temp = 15,
  type = "unvented"
)
#> [1] 1.959614