Retrieves daily summary observations from the Iowa Environmental Mesonet (IEM).
Value
A tibble containing daily summary observations returned by IEM, with
station identifiers in station_id when returned. Units and available
variables vary by network.
Details
Use either date for all stations in a network on one local date, or year
and optional month for a longer station or network request. Do not supply
date together with year or month.
References
Iowa Environmental Mesonet API: https://mesonet.agron.iastate.edu/api/
IEM API v1 documentation: https://mesonet.agron.iastate.edu/api/1/docs