Retrieves fire weather data in FW13 format for one station and date range.
Details
Kansas Mesonet data are preliminary and subject to revision. Cite the Kansas Mesonet when sharing, publishing, or otherwise disseminating data accessed with this function. A suggested citation format is: Kansas Mesonet, year: webpage title. Accessed date, webpage URL. Review the Kansas Mesonet data usage policy before automated use; automated page scraping or data ingesting without written consent is not permitted.
References
Kansas Mesonet data usage policy: https://mesonet.k-state.edu/about/usage/